@@ -3,6 +3,8 @@ from __future__ import annotations
 import argparse
 import ast
 import re
+import shutil
+import subprocess
 from pathlib import Path
 
 from django.apps import apps
@@ -159,6 +161,13 @@ class Command(BaseCommand):
         new_path.write_text(new_content)
         max_migration_txt.write_text(f"{new_name}\n")
 
+        black_path = shutil.which("black")
+        if black_path:  # pragma: no cover
+            subprocess.run(
+                [black_path, "--fast", "--", new_path],
+                capture_output=True,
+            )
+
         self.stdout.write(
             f"Renamed {rebased_migration_path.parts[-1]} to {new_path.parts[-1]},"
             + " updated its dependencies, and updated max_migration.txt."
